@@ -1,8 +1,10 @@
 #!/usr/bin/env python
 
-"""Usage:
-    haste.py [-r] [-]
-    haste.py [-r] FILE
+"""haste - a client to hastebin.com.
+
+Usage:
+    haste [-r] [-]
+    haste [-r] FILE
 
 -             read from stdin.
 FILE          read from a file.
@@ -39,5 +41,10 @@ def run(**kwargs):
         url = "%s/%s\n" % (BASEURL, json.loads(response.text)['key'])
     sys.stdout.write(url)
 
+
+def main():
+    run(**kwargs)
+
+
 if __name__ == "__main__":
     run(**kwargs)
